==> cobs-0.6.tgz: cobs-0.06/search.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="search.php";
 $READPROGNAME="read.php";
  //QueryO
 if (!isset($VERSION)) $VERSION="unv";
 if (!isset($strongflag)) $strongflag=0;
 if (!isset($TABFLAG)) $TABFLAG=0;
 $oldv=$VERSION;
 if (strcmp($VERSION,"kjv")==0) $stronged=1;
 elseif (strcmp($VERSION,"unv")==0) $stronged=1;
 else $stronged=0;
 $oldkeyword=$keyword;
 if ($orig==1)//TwO Greek strong number
 {
	if ($stronged==0) 
	{
		echo "<h2>䴩Strong number <h2>";
		exit;
	}
	// sSN > 5626HWNOWTG
	if ( ((int) $keyword) > 5626)
		$revkey="({$keyword})";
	else    $revkey="&lt;{$keyword}&gt;";
	$keyword=sprintf("G%d>",$keyword);
	$sstrong=1;
 }
 elseif ($orig==2)//TwO Heb strong number
 {
	if ($stronged==0) 
	{
		echo "<h2>䴩Strong number <h2>";
		exit;
	}
	// ¬SN >= 8680 HWNOWTG
	if ( ((int) $keyword) >= 8680)
		$revkey="({$keyword})";
	else    $revkey="&lt;0{$keyword}&gt;";
	$keyword=sprintf("H0%d>",$keyword);
	$sstrong=1;
 }
 else //g媩Sstrong number
  {
	$sstrong=0;
 	if (strcmp($VERSION,"kjv")==0) $VERSION="nstrkjv";
 	elseif (strcmp($VERSION,"unv")==0) $VERSION="nstrunv";
 	$revkey=$keyword;
  }
 /******* Bzd߽dD *********/
 if (($range_eid>0) || ($range_bid>0)) $RANGE=3; //pGwgANOĤTتp
 switch ($RANGE)
 {
	case 0: $RANGELIMIT=""; break; //㥻tg
	case 1: $RANGELIMIT="and main.id>39"; break; //s
	case 2: $RANGELIMIT="and main.id<40"; break; //¬
	case 3: 
		if ($range_eid<$range_bid) //
			{
				$idtmp=$range_eid;
				$range_eid=$range_bid;
				$range_bid=$idtmp;
			}
		if (($range_eid ==0)&&($range_bid ==0)) //SNO㥻tg
			{
				$range_bid=1;
				$range_eid=66;
			}
		if ($range_bid==0) $range_bid=$range_eid; //SNO@
		$RANGELIMIT="and main.id>=$range_bid and main.id<=$range_eid";
		break;
 }
 if ($updatemode)
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,$VERSION.username from $VERSION,main where main.engs=$VERSION.engs $RANGELIMIT and $VERSION.txt like '%$keyword%' order by $VERSION.id"; 
 else
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id from $VERSION,main where main.engs=$VERSION.engs $RANGELIMIT and $VERSION.txt like '%$keyword%' order by $VERSION.id"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //d߸ƪY
 if ($updatemode)
 	$THEADER=array("W","`","J","g");
 else
 	$THEADER=array("W","`","g");
  //C@
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 require("strong.php");
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
 if (strlen($keyword)==0)
 {
	echo "SJd߸ơIЦAդ@I\n";
 	exit;
 }
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echo "@ $numrow AƤӦhFAЭקd߱AdI";
	exit;
   }
 if ($numrow==0)
   {
   	echo "dơAЭקd߱AdI";
	exit;
   }
 $numfield=db_NumFields($result);
 /******** LX ********/
   echo "<head><title>Bible Search Result: $oldkeyword</title></head>\n";
 $PGEND=$PGBEG+$PGNUM-1;
 if ($PGEND>($numrow-1))
 {
	$PGEND=$numrow-1;
 }
 if ($PGBEG>=$PGNUM)
 {
   $a=$PGBEG-$PGNUM;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"VERSION\" value=\"$oldv\">\n";
   echo "<input type=\"hidden\" name=\"RANGE\" value=\"$RANGE\">\n";
   echo "<input type=\"hidden\" name=\"range_bid\" value=\"$range_bid\">\n";
   echo "<input type=\"hidden\" name=\"range_eid\" value=\"$range_eid\">\n";
   echo "<input type=\"hidden\" name=\"TABFLAG\" value=\"$TABFLAG\">\n";
   echo "<input type=\"hidden\" name=\"strongflag\" value=\"$strongflag\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"orig\" value=\"$orig\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"W@\">\n";
   echo "</form></center>\n";
 }
 $fpt=$PGBEG+1;
 echo "`@ $numrow ơAثeѲ $fpt }lL<br>\n";
 if ($TABFLAG)
 {
 	echo "<FONT COLOR=$COLOR><table $tabout>\n<tr>";
	if ($updatemode) $fpcnt=4;
        else $fpcnt=3;
 	for ($fpt=0;$fpt<$fpcnt;$fpt++)
 	{
    		$special=htmlspecialchars($THEADER[$fpt]);//SrBz
    		echo "<td align=center>$special</td>";
 	}
 	echo "</tr>";
 }
 /****uLX *****/
 for($a=$PGBEG;$a<=$PGEND;$a++)
   {
      if ($TABFLAG)
      {
         echo "<tr>";
      }
      $ARAW=db_fetch_row($result,$a); //Ū@O
      if ($TABFLAG)
      {
        $special=htmlspecialchars(trim($ARAW[0]));//SrBz
      	echo "<td>$special</td>";
        $special=htmlspecialchars($ARAW[1]);//SrBz
        echo "<td><a href=\"$READPROGNAME?id=$ARAW[3]&VERSION=$oldv&strongflag=$strongflag&TABFLAG=$TABFLAG\">$special</a></td>";
        if ($updatemode) echo "<td>$ARAW[4]</td>";
      }
      else //L
      {
	$special1=htmlspecialchars($ARAW[0]);//SrBz
        $special=htmlspecialchars($ARAW[1]);//SrBz
      echo "<a href=\"$READPROGNAME?id=$ARAW[3]&VERSION=$oldv&strongflag=$strongflag&TABFLAG=$TABFLAG\">$special1 $special</a>  ";
        if ($updatemode) echo "<td>$ARAW[4]</td>";
      }
      /****Bzg*****/
      $bibletex=$ARAW[2];
      if ($stronged) $bibletex=procstrong($strongflag,$bibletex);	
      if ($TABFLAG) echo "<td>";
      $pos=strpos($bibletex,$revkey);
      while (!($pos===false))
      {
	$pretex=substr($bibletex,0,$pos);
        $newpos=$pos+strlen($revkey);
	$bibletex=substr($bibletex,$newpos);
        //echo "BIBLE=$bibletex";
	if ($stronged) $special=$pretex;
	else $special=htmlspecialchars($pretex);
	
        echo "$special</font><font color=$KEYCOLOR>$revkey</font><font color=$COLOR>";
        $pos=strpos($bibletex,$revkey);
      }
      if ($stronged) $special=$bibletex;
      else $special=htmlspecialchars($bibletex);
      if ($TABFLAG)
		echo "$special</td>";
      else 
		echo "$special<br>";
      if ($TABFLAG)
      		echo "</tr>\n";
   }
   if ($TABFLAG)
   		echo "</table></font>\n";
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"VERSION\" value=\"$oldv\">\n";
   echo "<input type=\"hidden\" name=\"RANGE\" value=\"$RANGE\">\n";
   echo "<input type=\"hidden\" name=\"range_bid\" value=\"$range_bid\">\n";
   echo "<input type=\"hidden\" name=\"range_eid\" value=\"$range_eid\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"TABFLAG\" value=\"$TABFLAG\">\n";
   echo "<input type=\"hidden\" name=\"orig\" value=\"$orig\">\n";
   echo "<input type=\"hidden\" name=\"strongflag\" value=\"$strongflag\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"U@\">\n";
   echo "</form></center>\n";
 }
  /***** o̥[J ****/
  $a=0;
  $poldkeyword=urlencode($oldkeyword);
  echo "<center>G&nbsp;&nbsp;";
  for ($recpt=0;$recpt<=$numrow-1;$recpt=$recpt+$PGNUM)
  {
	$a=$a+1;
	if ($recpt!=$PGBEG) //O
	{
	 echo "&nbsp;<a href=\"$PROGNAME?PGBEG={$recpt}&VERSION={$oldv}&keyword={$poldkeyword}&TABFLAG={$TABFLAG}&orig={$orig}&strongflag={$strongflag}&RANGE={$RANGE}&range_bid={$range_bid}&range_eid={$range_eid}\">{$a}</a>&nbsp;\n";
	}
	else echo "&nbsp;<font color=\"red\">{$a}</font>&nbsp;";
  }
  echo "</center>";
   echo "<center><a href=\"$RETURNADD1\">sd</a></center><br>\n";
   if ($stronged)
   {
echo "<hr>\nKJV + Strongs and lexicons were adapted from the Online Bible. It used by permission and are copyrighted by Timnathserah Inc.";
   }

?>

==> cobs-0.7.tgz: cobs-0.7/search.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="search.php";
 $READPROGNAME="read.php";
 /************* GET ܼ ***************/
  $VERSION=$_REQUEST["VERSION"];//
  $strongflag=(int) $_REQUEST["strongflag"];//nnshow strong iH]wprefer
  $TABFLAG=(int) $_REQUEST["TABFLAG"];//iܤ覡 iH]w prefer
  $orig=(int) $_REQUEST["orig"];      //0Gg 1:þs 2:ƧBӤs
  $keyword=$_REQUEST["keyword"];      //d߸
  $RANGE=(int) $_REQUEST["RANGE"];    //d߼Ҧ 0G 1Gs 2:¬ 3:d
  $range_bid=(int) $_REQUEST["range_bid"]; //ddߤ}lg
  $range_eid=(int) $_REQUEST["range_eid"]; //ddߤg

  //QueryO
 if (strlen($VERSION)==0) $VERSION="unv";
 $oldv=$VERSION;
 if (strcmp($VERSION,"kjv")==0) $stronged=1;
 elseif (strcmp($VERSION,"unv")==0) $stronged=1;
 else $stronged=0;
 $oldkeyword=$keyword;
 if ($orig==1)//TwO Greek strong number
 {
	if ($stronged==0) 
	{
		echo "<h2>䴩Strong number <h2>";
		exit;
	}
	// sSN > 5626HWNOWTG
	if ( ((int) $keyword) > 5626)
		$revkey="({$keyword})";
	else    $revkey="&lt;{$keyword}&gt;";
	$keyword=sprintf("G%d>",$keyword);
	$sstrong=1;
 }
 elseif ($orig==2)//TwO Heb strong number
 {
	if ($stronged==0) 
	{
		echo "<h2>䴩Strong number <h2>";
		exit;
	}
	// ¬SN >= 8680 HWNOWTG
	if ( ((int) $keyword) >= 8680)
		$revkey="({$keyword})";
	else    $revkey="&lt;0{$keyword}&gt;";
	$keyword=sprintf("H0%d>",$keyword);
	$sstrong=1;
 }
 else //g媩Sstrong number
  {
	$sstrong=0;
 	if (strcmp($VERSION,"kjv")==0) $VERSION="nstrkjv";
 	elseif (strcmp($VERSION,"unv")==0) $VERSION="nstrunv";
 	$revkey=$keyword;
  }
 /******* Bzd߽dD *********/
 if (($range_eid>0) || ($range_bid>0)) $RANGE=3; //pGwgANOĤTتp
 switch ($RANGE)
 {
	case 0: $RANGELIMIT=""; break; //㥻tg
	case 1: $RANGELIMIT="and main.id>39"; break; //s
	case 2: $RANGELIMIT="and main.id<40"; break; //¬
	case 3: 
		if ($range_eid<$range_bid) //
			{
				$idtmp=$range_eid;
				$range_eid=$range_bid;
				$range_bid=$idtmp;
			}
		if (($range_eid ==0)&&($range_bid ==0)) //SNO㥻tg
			{
				$range_bid=1;
				$range_eid=66;
			}
		if ($range_bid==0) $range_bid=$range_eid; //SNO@
		$RANGELIMIT="and main.id>=$range_bid and main.id<=$range_eid";
		break;
 }
 if ($updatemode)
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,$VERSION.username from $VERSION,main where main.engs=$VERSION.engs $RANGELIMIT and $VERSION.txt like '%$keyword%' order by $VERSION.id"; 
 else
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id from $VERSION,main where main.engs=$VERSION.engs $RANGELIMIT and $VERSION.txt like '%$keyword%' order by $VERSION.id"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //d߸ƪY
 if ($updatemode)
 	$THEADER=array("W","`","J","g");
 else
 	$THEADER=array("W","`","g");
  //C@
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 require("strong.php");
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
 if (strlen($keyword)==0)
 {
	echo "SJd߸ơIЦAդ@I\n";
 	exit;
 }
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echo "@ $numrow AƤӦhFAЭקd߱AdI";
	exit;
   }
 if ($numrow==0)
   {
   	echo "dơAЭקd߱AdI";
	exit;
   }
 $numfield=db_NumFields($result);
 /******** LX ********/
   echo "<head><title>Bible Search Result: $oldkeyword</title>\n";
 echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 echo "</head>\n";
 $PGEND=$PGBEG+$PGNUM-1;
 if ($PGEND>($numrow-1))
 {
	$PGEND=$numrow-1;
 }
 if ($PGBEG>=$PGNUM)
 {
   $a=$PGBEG-$PGNUM;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"VERSION\" value=\"$oldv\">\n";
   echo "<input type=\"hidden\" name=\"RANGE\" value=\"$RANGE\">\n";
   echo "<input type=\"hidden\" name=\"range_bid\" value=\"$range_bid\">\n";
   echo "<input type=\"hidden\" name=\"range_eid\" value=\"$range_eid\">\n";
   echo "<input type=\"hidden\" name=\"TABFLAG\" value=\"$TABFLAG\">\n";
   echo "<input type=\"hidden\" name=\"strongflag\" value=\"$strongflag\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"orig\" value=\"$orig\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"W@\">\n";
   echo "</form></center>\n";
 }
 $fpt=$PGBEG+1;
 echo "`@ $numrow ơAثeѲ $fpt }lL<br>\n";
 if ($TABFLAG)
 {
 	echo "<FONT COLOR=$COLOR><table $tabout>\n<tr>";
	if ($updatemode) $fpcnt=4;
        else $fpcnt=3;
 	for ($fpt=0;$fpt<$fpcnt;$fpt++)
 	{
    		$special=htmlspecialchars($THEADER[$fpt]);//SrBz
    		echo "<td align=center>$special</td>";
 	}
 	echo "</tr>";
 }
 /****uLX *****/
 for($a=$PGBEG;$a<=$PGEND;$a++)
   {
      if ($TABFLAG)
      {
         echo "<tr>";
      }
      $ARAW=db_fetch_row($result,$a); //Ū@O
      if ($TABFLAG)
      {
        $special=htmlspecialchars(trim($ARAW[0]));//SrBz
      	echo "<td>$special</td>";
        $special=htmlspecialchars($ARAW[1]);//SrBz
        echo "<td><a href=\"$READPROGNAME?id=$ARAW[3]&VERSION=$oldv&strongflag=$strongflag&TABFLAG=$TABFLAG\" target=\"READ\">$special</a></td>";
        if ($updatemode) echo "<td>$ARAW[4]</td>";
      }
      else //L
      {
	$special1=htmlspecialchars($ARAW[0]);//SrBz
        $special=htmlspecialchars($ARAW[1]);//SrBz
      echo "<a href=\"$READPROGNAME?id=$ARAW[3]&VERSION=$oldv&strongflag=$strongflag&TABFLAG=$TABFLAG\" target=\"READ\">$special1 $special</a>  ";
        if ($updatemode) echo "<td>$ARAW[4]</td>";
      }
      /****Bzg*****/
      $bibletex=$ARAW[2];
      if ($stronged) $bibletex=procstrong($strongflag,$bibletex);	
      if ($TABFLAG) echo "<td>";
      $pos=strpos($bibletex,$revkey);
      while (!($pos===false))
      {
	$pretex=substr($bibletex,0,$pos);
        $newpos=$pos+strlen($revkey);
	$bibletex=substr($bibletex,$newpos);
        //echo "BIBLE=$bibletex";
	if ($stronged) $special=$pretex;
	else $special=htmlspecialchars($pretex);
	
        echo "$special</font><font color=$KEYCOLOR>$revkey</font><font color=$COLOR>";
        $pos=strpos($bibletex,$revkey);
      }
      if ($stronged) $special=$bibletex;
      else $special=htmlspecialchars($bibletex);
      if ($TABFLAG)
		echo "$special</td>";
      else 
		echo "$special<br>";
      if ($TABFLAG)
      		echo "</tr>\n";
   }
   if ($TABFLAG)
   		echo "</table></font>\n";
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"VERSION\" value=\"$oldv\">\n";
   echo "<input type=\"hidden\" name=\"RANGE\" value=\"$RANGE\">\n";
   echo "<input type=\"hidden\" name=\"range_bid\" value=\"$range_bid\">\n";
   echo "<input type=\"hidden\" name=\"range_eid\" value=\"$range_eid\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"TABFLAG\" value=\"$TABFLAG\">\n";
   echo "<input type=\"hidden\" name=\"orig\" value=\"$orig\">\n";
   echo "<input type=\"hidden\" name=\"strongflag\" value=\"$strongflag\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"U@\">\n";
   echo "</form></center>\n";
 }
  /***** o̥[J ****/
  $a=0;
  $poldkeyword=urlencode($oldkeyword);
  echo "<center>G&nbsp;&nbsp;";
  for ($recpt=0;$recpt<=$numrow-1;$recpt=$recpt+$PGNUM)
  {
	$a=$a+1;
	if ($recpt!=$PGBEG) //O
	{
	 echo "&nbsp;<a href=\"$PROGNAME?PGBEG={$recpt}&VERSION={$oldv}&keyword={$poldkeyword}&TABFLAG={$TABFLAG}&orig={$orig}&strongflag={$strongflag}&RANGE={$RANGE}&range_bid={$range_bid}&range_eid={$range_eid}\">{$a}</a>&nbsp;\n";
	}
	else echo "&nbsp;<font color=\"red\">{$a}</font>&nbsp;";
  }
  echo "</center>";
   echo "<center><a href=\"$RETURNADD1\">sd</a></center><br>\n";
   if ($stronged)
   {
echo "<hr>\nKJV + Strongs and lexicons were adapted from the Online Bible. It used by permission and are copyrighted by Timnathserah Inc.";
   }

?>
